@@ -306,9 +306,15 @@ class Generator:
         name = self._script.utilities.displayedText(obj)
         if obj.getRole() == pyatspi.ROLE_COMBO_BOX:
             children = self._script.utilities.selectedChildren(obj)
-            if not children and obj.childCount:
-                children = self._script.utilities.selectedChildren(obj[0])
-            children = children or [child for child in obj]
+            if not children:
+                try:
+                    children = self._script.utilities.selectedChildren(obj[0])
+                except:
+                    pass
+            try:
+                children = children or [child for child in obj]
+            except:
+                pass
             names = map(self._script.utilities.displayedText, children)
             names = list(filter(lambda x: x, names))
             if len(names) == 1:
@@ -335,7 +341,7 @@ class Generator:
                     link = obj.parent
                 if link:
                     basename = self._script.utilities.linkBasename(link)
-                    if basename:
+                    if basename and basename.isalpha():
                         result.append(basename)
         # To make the unlabeled icons in gnome-panel more accessible.
         try:
@@ -864,12 +870,11 @@ class Generator:
         if self._script.utilities.isLayoutOnly(obj):
             return []
 
-        try:
-            table = obj.queryTable()
-        except:
+        rows, cols = self._script.utilities.rowAndColumnCount(obj)
+        if rows < 0 or cols < 0:
             return []
 
-        return [messages.tableSize(table.nRows, table.nColumns)]       
+        return [messages.tableSize(rows, cols)]
 
     def _generateTableCellRow(self, obj, **args):
         """Orca has a feature to automatically read an entire row of a table
@@ -932,6 +937,8 @@ class Generator:
                             result.append(braille.Region(
                                 object_properties.TABLE_CELL_DELIMITER_BRAILLE))
                         result.extend(cellResult)
+
+                result.extend(self._generatePositionInList(obj, **args))
             else:
                 result.extend(self._generateRealTableCell(obj, **args))
         else:
@@ -996,6 +1003,21 @@ class Generator:
 
         return [displayedText]
 
+    def _generateListItemMarker(self, obj, **args):
+        startOffset = args.get('startOffset', 0)
+        if not (0 <= startOffset <= 1):
+            return []
+
+        endOffset = args.get('endOffset')
+        if endOffset is not None and endOffset == startOffset:
+            return []
+
+        listItemMarker = self._script.utilities.getListItemMarkerText(obj)
+        if listItemMarker:
+            return [listItemMarker]
+
+        return []
+
     #####################################################################
     #                                                                   #
     # Tree interface information                                        #
@@ -1146,6 +1168,9 @@ class Generator:
     def _generatePageSummary(self, obj, **args):
         return []
 
+    def _generatePositionInList(self, obj, **args):
+        return []
+
     def _generateProgressBarIndex(self, obj, **args):
         return []
 
@@ -1354,6 +1379,8 @@ class Generator:
                     return object_properties.ROLE_SUBTITLE
 
         if self._script.utilities.isLandmark(obj):
+            if self._script.utilities.isLandmarkWithoutType(obj):
+                return ''
             if self._script.utilities.isLandmarkBanner(obj):
                 return object_properties.ROLE_LANDMARK_BANNER
             if self._script.utilities.isLandmarkComplementary(obj):
